# Commands

## Reset Primary Keys

This command resets the primary keys for a specific model in a selected app by deleting data and resetting primary keys.

```bash
python manage.py reset_primary_keys
```

## Reset Models

This command resets the data for a specific model in a selected app.

```bash
python manage.py reset_models
```

## Reset Database

This command resets the database by running migrations and clearing data.

```bash
python manage.py reset_database
```